#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui>
#include "keys.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();
    QSettings *settings;
    QString path;
    QMap<int,QString>roms;
    keys *keyopt;
    bool fps_show;
    bool abbey;
    bool logged;
    bool fscreen;
    bool accel;
    int cycle,frameskiping,save_slot;
    QString selected_core;
private:
    QMenu opt;
    QAction *fpsm;
    QAction *abbm;
    //QAction *ldbg;
    QAction *fscr;
    QAction *accelm;
    QAction *eas;
    QString prev;
    QList<QAction*> cyclem;
    QList<QAction*> framem;
    QList<QAction*> corem;
public slots:
   // void show_log();
   // void bug();
    void about();
    void fm_skip_ch();
    void set_core();
    void save_ch();
    void cml_ch();
    void runGame();
    void select_dir();
    void currentTextChanged ( const QString & currentText );
private:
    Ui::MainWindow *ui;
};

#endif // MAINWINDOW_H
